==> pips-sc65_66s-2.6.2.tar.gz: pips-sc65_66s-2.6.2/src/prtOpt.h <==
/*
 * Photo Image Print System
 * Copyright (C) SEIKO EPSON CORPORATION 2004.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON KOWA Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON KOWA PUBLIC LICENCE and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON KOWA PUBLIC LICENCE.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifndef __OPT_RSC__
#define __OPT_RSC__

#include "pipsDef.h"


/* Inset Defult */
#define	PIPS_INKSET_DEFAULT PIPS_INKSET_CMYK

#ifndef	_ONLY_NEED_DEFAULT_

/* Option Entry */
char *inkEntry[] = {
        "COLOR", "MONO",
        NULL
};

char *binEntry[] = {
        "AUTO", "T4AUTO",
        NULL
};

/* ASF */
char *mediaSizeEntry[] = {
    "A4",	"B5",	"A5",	"LT",	"LGL",	"EXE",
    "HLT",	"A6",	"INDEX5",	"INDEX8",	"ENV10",	"ENVDL",
    "ENVC6",	"ENV5X8",	"PHOTO",	"4X6FULL",	"PP100",
    NULL
};

/* ROLL */
char *mediaSizeEntry_R[] = {
        NULL
};

/* ROLL-Banner */
char *mediaSizeEntry_TR[] = {
        NULL
};

/* ASF-No Margin  */
char *mediaSizeEntry_NMA[] = {
    "4X6FULL",   "PP100",
        NULL
};

char *resolutionEntry[] = {
        "120", "360", "720",
        NULL
};

/* Caution:				*/
/* PPI+LK -> cannot use PSGLOS,PHOTOW	*/
char *mediaTypeEntry[] = {
        "PLAIN", "PLAIN_BKSAVE", "BWP", "PMMATT", "EPP_P", "GPAPER",  "OHP",
        NULL
};

char *colorModeEntry[] = {
       "PHOTO", "GRAPH", "NONE",
        NULL
};

char *halftoneEntry[] = {
        "ED",
        NULL
};

char *levelEntry[] = {
        "DRAFT", "STD360", "FINE720", "SFINE720",
        "PHOTO1440",  "PHOTO2880",  "SPHOTO2880",
        NULL
};

char *multiPageEntry[] = {
        "1", "2", "4",
        NULL
};

char *autoCutEntry[] = {
        "NONE",
        NULL
};


/* pModeCol     :       Color
   pModeMono    :       Monochrome

   MediaNumber  :       see pipsDef.h
   Input        :       1:120/180, 2:360, 4:720
   Halftone     :       <or> 1:ED 2:DB
   HighSpeed    :       0:OFF 1:ON 2:ON/OFF
   Quality      :       0xXXX
                          ||+---- at Input 1
                          |+----- at Input 2
                          +------ at Input 4

*/
short pModeCol[] = {
        /* mediaName            Input           MicroWeave      */
        /* & MediaNumber                Halftone        HighSpeed   Quality */

        /* PLAIN */
        PIPS_MED_PLAIN,         1,      1,      0,      1,      0x000,
        PIPS_MED_PLAIN,         2,      1,      0,      2,      0x010,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x200,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x300,

        /* PLAIN_BK_SAVE */
        PIPS_MED_PLAIN_BKSAVE,  2,      1,      0,      2,      0x010,

        /* BWP */
        PIPS_MED_BWP,           1,      1,      0,      1,      0x000,
        PIPS_MED_BWP,           2,      1,      0,      2,      0x010,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x200,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x300,

        /* PMMATT */
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x200,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x300,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x400,

        /* EPP_P */
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x300,
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x400,
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x500,
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x600,

        /* GPAPER */
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x300,
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x400,

        /* OHP */
        PIPS_MED_TRANSPARENCY,  2,      1,      1,      0,      0x020,
        -1
};

short pModeMono[] = {
        /* mediaName            Input           MicroWeave      Quality */
        /* & MediaNumber                Halftone        HighSpeed       */
        /* PLAIN */
        PIPS_MED_PLAIN,         1,      1,      0,      1,      0x000,
        PIPS_MED_PLAIN,         2,      1,      0,      2,      0x010,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x200,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x300,

        /* PLAIN_BK_SAVE */
        PIPS_MED_PLAIN_BKSAVE,  2,      1,      0,      2,      0x010,

        /* BWP */
        PIPS_MED_BWP,           1,      1,      0,      1,      0x000,
        PIPS_MED_BWP,           2,      1,      0,      2,      0x010,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x200,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x300,

        /* PMMATT */
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x200,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x300,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      0,      0x400,

        /* EPP_P */
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x300,
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x400,
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x500,
        PIPS_MED_EPP_P,         4,      1,      1,      2,      0x600,

        /* GPAPER */
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x300,
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x400,

        /* OHP */
        PIPS_MED_TRANSPARENCY,  2,      1,      1,      0,      0x020,
        -1
};

/* Bin="T4AUTO" ̵ˤʤ⡼ID (color,black )   */
/* t4ΤȤ_for_<̾>򳰤				*/
short de_param_mode_t4[] = {
	0, 1 ,2, 3, 4, 5, 6, 7, 8, 15, 18, -1
};

/* monoѥơ֥Ѥޤ */
short de_param_mode_t4_mono[] = {
	0, 1 ,2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 15, 18, -1
};
#endif /* _ONLY_NEED_DEFAULT_ */

#endif /* __OPT_RSC__ */

==> pips-sc84_83s-2.6.2.tar.gz: pips-sc84_83s-2.6.2/src/prtOpt.h <==
/*
 * Photo Image Print System
 * Copyright (C) SEIKO EPSON CORPORATION 2004.
 *
 *  This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
 *
 * As a special exception, EPSON KOWA Corporation gives permission to
 * link the code of this program with libraries which are covered by
 * the EPSON KOWA PUBLIC LICENCE and distribute their linked
 * combinations.  You must obey the GNU General Public License in all
 * respects for all of the code used other than the libraries which
 * are covered by EPSON KOWA PUBLIC LICENCE.
 */
#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#ifndef __OPT_RSC__
#define __OPT_RSC__

#include "pipsDef.h"


/* Inset Defult */
#define	PIPS_INKSET_DEFAULT PIPS_INKSET_CMYK

#ifndef	_ONLY_NEED_DEFAULT_

/* Option Entry */
char *inkEntry[] = {
        "COLOR", "MONO",
        NULL
};

char *binEntry[] = {
        "AUTO", "T4AUTO",
        NULL
};

/* ASF */
char *mediaSizeEntry[] = {
    "A4",	"B5",	"A5",	"LT",	"LGL",	"EXE",
    "HLT",	"A6",	"INDEX5",	"INDEX8",	"ENV10",	"ENVDL",
    "ENVC6",	"ENV5X8",	"PHOTO",	"4X6FULL",	"PP100",
    NULL
};

/* ROLL */
char *mediaSizeEntry_R[] = {
        NULL
};

/* ROLL-Banner */
char *mediaSizeEntry_TR[] = {
        NULL
};

/* ASF-No Margin  */
char *mediaSizeEntry_NMA[] = {
    "A4",  "4X6FULL",   "PP100",
        NULL
};

char *resolutionEntry[] = {
        "180", "360", "720",
        NULL
};

/* Caution:				*/
/* PPI+LK -> cannot use PSGLOS,PHOTOW	*/
char *mediaTypeEntry[] = {
        "PLAIN", "BWP", "PMMATT", "EPP_P", "GPAPER",  "OHP",
        NULL
};

char *colorModeEntry[] = {
       "PHOTO", "GRAPH", "NONE",
        NULL
};

char *halftoneEntry[] = {
        "ED",
        NULL
};

char *levelEntry[] = {
        "DRAFT", "STD360", "FINE720", "SFINE720", 
        "PHOTO1440",  "PHOTO2880",  "SPHOTO2880",
        NULL
};

char *multiPageEntry[] = {
        "1", "2", "4",
        NULL
};

char *autoCutEntry[] = {
        "NONE",
        NULL
};


/* pModeCol     :       Color
   pModeMono    :       Monochrome

   MediaNumber  :       see pipsDef.h
   Input        :       1:120/180, 2:360, 4:720
   Halftone     :       <or> 1:ED 2:DB
   HighSpeed    :       0:OFF 1:ON 2:ON/OFF
   Quality      :       0xXXX
                          ||+---- at Input 1
                          |+----- at Input 2
                          +------ at Input 4

*/
short pModeCol[] = {
        /* mediaName            Input           MicroWeave      */
        /* & MediaNumber                Halftone        HighSpeed   Quality */

        /* PLAIN */
        PIPS_MED_PLAIN,         1,      1,      0,      1,      0x000,
        PIPS_MED_PLAIN,         2,      1,      0,      2,      0x010,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x200,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x300,

        /* BWP */
        PIPS_MED_BWP,           1,      1,      0,      1,      0x000,
        PIPS_MED_BWP,           2,      1,      0,      2,      0x010,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x200,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x300,

        /* PMMATT */
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x200,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x300,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x400,

        /* EPP_P */
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x300,
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x400,
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x500,
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x600,

        /* GPAPER */
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x300,
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x400,

        /* OHP */
        PIPS_MED_TRANSPARENCY,  2,      1,      1,      0,      0x020,
        -1
};

short pModeMono[] = {
        /* mediaName            Input           MicroWeave      Quality */
        /* & MediaNumber                Halftone        HighSpeed       */
        /* PLAIN */
        PIPS_MED_PLAIN,         1,      1,      0,      1,      0x000,
        PIPS_MED_PLAIN,         2,      1,      0,      2,      0x010,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x200,
        PIPS_MED_PLAIN,         4,      1,      1,      2,      0x300,

        /* BWP */
        PIPS_MED_BWP,           1,      1,      0,      1,      0x000,
        PIPS_MED_BWP,           2,      1,      0,      2,      0x010,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x200,
        PIPS_MED_BWP,           4,      1,      1,      2,      0x300,

        /* PMMATT */
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x200,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      2,      0x300,
        PIPS_MED_MATT_HEAVY,    4,      1,      1,      0,      0x400,

        /* EPP_P */
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x300,
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x400,
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x500,
        PIPS_MED_EPP_P,    4,      1,      1,      2,      0x600,

        /* GPAPER */
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x300,
        PIPS_MED_GLOSSYPAPER,   4,      1,      1,      2,      0x400,

        /* OHP */
        PIPS_MED_TRANSPARENCY,  2,      1,      1,      0,      0x020,
        -1
};

/* Bin="T4AUTO" ̵ˤʤE⡼ID (color,black )   */
/* t4ΤȤ_for_<E>򳰤				*/
short de_param_mode_t4[] = {
	0, 1, 2, 3, 4, 5, 6,7,14,17,
	 -1
};

/* for mono */
short de_param_mode_t4_mono[] = {
      0, 1, 2, 3, 4, 5, 6,7,8,9,10,14,17,
      -1
};

#endif /* _ONLY_NEED_DEFAULT_ */

#endif /* __OPT_RSC__ */
